@@ -280,6 +280,7 @@ pub unsafe fn copy_from_rust(ccx_s_options: *mut ccx_s_options, options: Options
     (*ccx_s_options).scc_framerate = options.scc_framerate;
     // Also copy to enc_cfg so the encoder uses the same frame rate for SCC output
     (*ccx_s_options).enc_cfg.scc_framerate = options.scc_framerate;
+    (*ccx_s_options).enc_cfg.scc_accurate_timing = options.scc_accurate_timing.into();
     #[cfg(feature = "with_libcurl")]
     {
         if options.curlposturl.is_some() {
@@ -539,6 +540,7 @@ pub unsafe fn copy_to_rust(ccx_s_options: *const ccx_s_options) -> Options {
     options.out_interval = (*ccx_s_options).out_interval;
     options.segment_on_key_frames_only = (*ccx_s_options).segment_on_key_frames_only != 0;
     options.scc_framerate = (*ccx_s_options).scc_framerate;
+    options.scc_accurate_timing = (*ccx_s_options).enc_cfg.scc_accurate_timing != 0;
 
     // Handle optional features with conditional compilation
     #[cfg(feature = "with_libcurl")]
@@ -982,6 +984,7 @@ impl CType<encoder_cfg> for EncoderConfig {
             },
             extract_only_708: self.extract_only_708 as _,
             scc_framerate: 0, // Will be set from ccx_options.scc_framerate in copy_to_c
+            scc_accurate_timing: 0, // Will be set from ccx_options.scc_accurate_timing in copy_to_c
         }
     }
 }
